@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.0700'; # VERSION
+our $VERSION = '0.0800'; # VERSION
 
 use Carp qw(croak);
 use MIME::Entity;
@@ -70,6 +70,13 @@ sub get_webhooks {
     return $self->get("/room/$room/webhook", $args{query} || {});
 }
 
+sub get_webhook {
+    my ($self, $room, $webhook_id) = @_;
+    croak '$room is required' unless $room;
+    croak '$webhook_id is required' unless $webhook_id;
+    return $self->get("/room/$room/webhook/$webhook_id")
+}
+
 sub create_webhook {
     my ($self, $room, $data) = @_;
     croak '$room is required' unless $room;
@@ -214,7 +221,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.0700
+version 0.0800
 
 =head1 SYNOPSIS
 
@@ -361,6 +368,10 @@ Example response:
       startIndex => 0,
     }
 
+=head2 get_webhook
+
+    get_webhook($room, $webhook_id);
+
 =head2 create_webhook
 
     create_webhook($room, {
@@ -369,6 +380,10 @@ Example response:
         name  => 'hook1',
     });
 
+=head delete_webhook
+
+    delete_webhook($room, $webhook_id);
+
 =head2 send_private_msg
 
     send_private_msg($user, { message => 'allo' });
